Welcome to mirror list, hosted at ThFree Co, Russian Federation.

github.com/mono/mono.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
-rw-r--r--docs/ignore2
-rw-r--r--mono/mini/exceptions-amd64.c4
-rw-r--r--mono/mini/exceptions-ppc.c2
-rw-r--r--mono/mini/exceptions-x86.c4
-rw-r--r--mono/mini/mini-exceptions.c12
-rw-r--r--mono/mini/mini-posix.c2
-rw-r--r--mono/mini/mini-runtime.c6
-rw-r--r--mono/mini/mini.h2
8 files changed, 17 insertions, 17 deletions
diff --git a/docs/ignore b/docs/ignore
index 7bff64fc91f..5946522e137 100644
--- a/docs/ignore
+++ b/docs/ignore
@@ -326,7 +326,7 @@ mono_poll
mono_dynamic_stream_reset
mono_domain_get_tls_offset
mono_domain_add_class_static_data
-mono_handle_native_sigsegv
+mono_handle_native_crash
mono_set_config_dir
mono_profiler_coverage_alloc
mono_profiler_coverage_free
diff --git a/mono/mini/exceptions-amd64.c b/mono/mini/exceptions-amd64.c
index 304135e6c9f..ae55ff54538 100644
--- a/mono/mini/exceptions-amd64.c
+++ b/mono/mini/exceptions-amd64.c
@@ -58,7 +58,7 @@ static LONG CALLBACK seh_unhandled_exception_filter(EXCEPTION_POINTERS* ep)
}
#endif
- mono_handle_native_sigsegv ("SIGSEGV", NULL, NULL);
+ mono_handle_native_crash ("SIGSEGV", NULL, NULL);
return EXCEPTION_CONTINUE_SEARCH;
}
@@ -777,7 +777,7 @@ altstack_handle_and_restore (MonoContext *ctx, MonoObject *obj, gboolean stack_o
MonoJitInfo *ji = mini_jit_info_table_find (mono_domain_get (), MONO_CONTEXT_GET_IP (ctx), NULL);
if (!ji)
- mono_handle_native_sigsegv ("SIGSEGV", NULL, NULL);
+ mono_handle_native_crash ("SIGSEGV", NULL, NULL);
mctx = *ctx;
diff --git a/mono/mini/exceptions-ppc.c b/mono/mini/exceptions-ppc.c
index 238de087412..3ec8d9f8558 100644
--- a/mono/mini/exceptions-ppc.c
+++ b/mono/mini/exceptions-ppc.c
@@ -666,7 +666,7 @@ mono_arch_handle_altstack_exception (void *sigctx, MONO_SIG_HANDLER_INFO_TYPE *s
abort ();
}
if (!ji)
- mono_handle_native_sigsegv ("SIGSEGV", sigctx, siginfo);
+ mono_handle_native_crash ("SIGSEGV", sigctx, siginfo);
/* setup a call frame on the real stack so that control is returned there
* and exception handling can continue.
* The frame looks like:
diff --git a/mono/mini/exceptions-x86.c b/mono/mini/exceptions-x86.c
index f2943c89ed1..9123fc57b51 100644
--- a/mono/mini/exceptions-x86.c
+++ b/mono/mini/exceptions-x86.c
@@ -62,7 +62,7 @@ LONG CALLBACK seh_unhandled_exception_filter(EXCEPTION_POINTERS* ep)
}
#endif
- mono_handle_native_sigsegv ("SIGSEGV", NULL, NULL);
+ mono_handle_native_crash ("SIGSEGV", NULL, NULL);
return EXCEPTION_CONTINUE_SEARCH;
}
@@ -1112,7 +1112,7 @@ mono_arch_handle_altstack_exception (void *sigctx, MONO_SIG_HANDLER_INFO_TYPE *s
if (stack_ovf)
exc = mono_domain_get ()->stack_overflow_ex;
if (!ji)
- mono_handle_native_sigsegv ("SIGSEGV", sigctx, siginfo);
+ mono_handle_native_crash ("SIGSEGV", sigctx, siginfo);
/* setup a call frame on the real stack so that control is returned there
* and exception handling can continue.
* If this was a stack overflow the caller already ensured the stack pages
diff --git a/mono/mini/mini-posix.c b/mono/mini/mini-posix.c
index 7f3082be2c0..8b103eb8bbf 100644
--- a/mono/mini/mini-posix.c
+++ b/mono/mini/mini-posix.c
@@ -220,7 +220,7 @@ MONO_SIG_HANDLER_FUNC (static, sigabrt_signal_handler)
if (!ji) {
if (mono_chain_signal (MONO_SIG_HANDLER_PARAMS))
return;
- mono_handle_native_sigsegv ("SIGABRT", ctx, info);
+ mono_handle_native_crash ("SIGABRT", ctx, info);
}
}
diff --git a/mono/mini/mini-runtime.c b/mono/mini/mini-runtime.c
index 932b859facd..0ac217fe0a1 100644
--- a/mono/mini/mini-runtime.c
+++ b/mono/mini/mini-runtime.c
@@ -2850,7 +2850,7 @@ MONO_SIG_HANDLER_FUNC (, mono_sigfpe_signal_handler)
if (!mono_do_crash_chaining && mono_chain_signal (MONO_SIG_HANDLER_PARAMS))
return;
- mono_handle_native_sigsegv ("SIGFPE", ctx, info);
+ mono_handle_native_crash ("SIGFPE", ctx, info);
if (mono_do_crash_chaining) {
mono_chain_signal (MONO_SIG_HANDLER_PARAMS);
return;
@@ -2916,7 +2916,7 @@ MONO_SIG_HANDLER_FUNC (, mono_sigsegv_signal_handler)
if (!mono_domain_get () || !jit_tls) {
if (!mono_do_crash_chaining && mono_chain_signal (MONO_SIG_HANDLER_PARAMS))
return;
- mono_handle_native_sigsegv ("SIGSEGV", ctx, info);
+ mono_handle_native_crash ("SIGSEGV", ctx, info);
if (mono_do_crash_chaining) {
mono_chain_signal (MONO_SIG_HANDLER_PARAMS);
return;
@@ -2963,7 +2963,7 @@ MONO_SIG_HANDLER_FUNC (, mono_sigsegv_signal_handler)
if (!mono_do_crash_chaining && mono_chain_signal (MONO_SIG_HANDLER_PARAMS))
return;
- mono_handle_native_sigsegv ("SIGSEGV", ctx, info);
+ mono_handle_native_crash ("SIGSEGV", ctx, info);
if (mono_do_crash_chaining) {
mono_chain_signal (MONO_SIG_HANDLER_PARAMS);
diff --git a/mono/mini/mini.h b/mono/mini/mini.h
index a4b2cb23dc1..e1686e90252 100644
--- a/mono/mini/mini.h
+++ b/mono/mini/mini.h
@@ -2850,7 +2850,7 @@ typedef gboolean (*MonoJitStackWalk) (StackFrameInfo *frame, MonoCont
void mono_exceptions_init (void);
gboolean mono_handle_exception (MonoContext *ctx, MonoObject *obj);
-void mono_handle_native_sigsegv (const char *signal, void *sigctx, MONO_SIG_HANDLER_INFO_TYPE *siginfo);
+void mono_handle_native_crash (const char *signal, void *sigctx, MONO_SIG_HANDLER_INFO_TYPE *siginfo);
MONO_API void mono_print_thread_dump (void *sigctx);
MONO_API void mono_print_thread_dump_from_ctx (MonoContext *ctx);
void mono_walk_stack_with_ctx (MonoJitStackWalk func, MonoContext *start_ctx, MonoUnwindOptions unwind_options, void *user_data);
diff --git a/mono/mini/mini-exceptions.c b/mono/mini/mini-exceptions.c
index cc51f543927..3d769c6460f 100644
--- a/mono/mini/mini-exceptions.c
+++ b/mono/mini/mini-exceptions.c
@@ -2425,13 +2425,13 @@ print_stack_frame_to_string (StackFrameInfo *frame, MonoContext *ctx, gpointer d
static gboolean handling_sigsegv = FALSE;
/*
- * mono_handle_native_sigsegv:
+ * mono_handle_native_crash:
*
* Handle a SIGSEGV received while in native code by printing diagnostic
* information and aborting.
*/
void
-mono_handle_native_sigsegv (const char *signal, void *ctx, MONO_SIG_HANDLER_INFO_TYPE *info)
+mono_handle_native_crash (const char *signal, void *ctx, MONO_SIG_HANDLER_INFO_TYPE *info)
{
#ifdef MONO_ARCH_USE_SIGACTION
struct sigaction sa;
@@ -2442,7 +2442,7 @@ mono_handle_native_sigsegv (const char *signal, void *ctx, MONO_SIG_HANDLER_INFO
return;
if (mini_get_debug_options ()->suspend_on_sigsegv) {
- mono_runtime_printf_err ("Received SIGSEGV, suspending...");
+ mono_runtime_printf_err ("Received %s, suspending...", signal);
#ifdef HOST_WIN32
while (1)
;
@@ -2558,7 +2558,7 @@ mono_handle_native_sigsegv (const char *signal, void *ctx, MONO_SIG_HANDLER_INFO
#else
void
-mono_handle_native_sigsegv (const char *signal, void *ctx, MONO_SIG_HANDLER_INFO_TYPE *info)
+mono_handle_native_crash (const char *signal, void *ctx, MONO_SIG_HANDLER_INFO_TYPE *info)
{
g_assert_not_reached ();
}
@@ -2425,13 +2425,13 @@ print_stack_frame_to_string (StackFrameInfo *frame, MonoContext *ctx, gpointer d
*
- * Handle a SIGSEGV received while in native code by printing diagnostic
- * information and aborting.
+ * Handle a native crash (e.g. SIGSEGV) while in native code by
+ * printing diagnostic information and aborting.
*/
void